package betterquesting.api2.client.gui.controls;

import betterquesting.api.api.ApiReference;
import betterquesting.api.api.QuestingAPI;
import betterquesting.api.enums.EnumLogic;
import betterquesting.api.enums.EnumQuestState;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.tasks.ITask;
import betterquesting.api.storage.IQuestSettings;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.resources.textures.GuiTextureColored;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.resources.textures.OreDictTexture;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.questing.QuestDatabase;
import betterquesting.storage.QuestSettings;
import com.mojang.realmsclient.gui.ChatFormatting;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.UUID;
import net.minecraft.client.Minecraft;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.init.Items;
import net.minecraft.nbt.NBTTagCompound;

/* loaded from: betterquesting_api2_client_gui_controls.jar:betterquesting/api2/client/gui/controls/PanelButtonQuest.class */
public class PanelButtonQuest extends PanelButtonStorage<DBEntry<IQuest>> {
    public final GuiRectangle rect;
    public final EntityPlayer player;

    public PanelButtonQuest(GuiRectangle rect, int id, String txt, DBEntry<IQuest> value) {
        super(rect, id, txt, value);
        this.rect = rect;
        this.player = Minecraft.func_71410_x().field_71439_g;
        EnumQuestState qState = value == null ? EnumQuestState.LOCKED : ((IQuest) value.getValue()).getState(QuestingAPI.getQuestingUUID(this.player));
        IGuiTexture txFrame = null;
        IGuiColor txIconCol = null;
        boolean main = value == null ? false : ((Boolean) ((IQuest) value.getValue()).getProperty(NativeProps.MAIN)).booleanValue();
        boolean lock = false;
        switch (AnonymousClass1.$SwitchMap$betterquesting$api$enums$EnumQuestState[qState.ordinal()]) {
            case 1:
                txFrame = main ? PresetTexture.QUEST_MAIN_0.getTexture() : PresetTexture.QUEST_NORM_0.getTexture();
                txIconCol = PresetColor.QUEST_ICON_LOCKED.getColor();
                lock = true;
                break;
            case 2:
                txFrame = main ? PresetTexture.QUEST_MAIN_1.getTexture() : PresetTexture.QUEST_NORM_1.getTexture();
                txIconCol = PresetColor.QUEST_ICON_UNLOCKED.getColor();
                break;
            case 3:
                txFrame = main ? PresetTexture.QUEST_MAIN_2.getTexture() : PresetTexture.QUEST_NORM_2.getTexture();
                txIconCol = PresetColor.QUEST_ICON_PENDING.getColor();
                break;
            case 4:
                txFrame = main ? PresetTexture.QUEST_MAIN_3.getTexture() : PresetTexture.QUEST_NORM_3.getTexture();
                txIconCol = PresetColor.QUEST_ICON_COMPLETE.getColor();
                break;
        }
        GuiTextureColored guiTextureColored = new GuiTextureColored(txFrame, txIconCol);
        setTextures(guiTextureColored, guiTextureColored, guiTextureColored);
        setIcon(new OreDictTexture(1.0f, value == null ? new BigItemStack(Items.field_151156_bN) : (BigItemStack) ((IQuest) value.getValue()).getProperty(NativeProps.ICON), false, true), 4);
        setActive(((IQuestSettings) QuestingAPI.getAPI(ApiReference.SETTINGS)).canUserEdit(this.player) || !lock);
    }

    /* renamed from: betterquesting.api2.client.gui.controls.PanelButtonQuest$1, reason: invalid class name */
    /* loaded from: betterquesting_api2_client_gui_controls.jar:betterquesting/api2/client/gui/controls/PanelButtonQuest$1.class */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$betterquesting$api$enums$EnumQuestState = new int[EnumQuestState.values().length];

        static {
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.LOCKED.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.UNLOCKED.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.UNCLAIMED.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.COMPLETED.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    @Override // betterquesting.api2.client.gui.controls.PanelButton
    public List<String> getTooltip(int mx, int my) {
        if (!getTransform().contains(mx, my)) {
            return null;
        }
        DBEntry<IQuest> value = getStoredValue();
        return value == null ? Collections.emptyList() : getQuestTooltip((IQuest) value.getValue(), this.player, value.getID());
    }

    private List<String> getQuestTooltip(IQuest quest, EntityPlayer player, int qID) {
        List<String> tooltip = getStandardTooltip(quest, player, qID);
        if (Minecraft.func_71410_x().field_71474_y.field_82882_x && ((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.EDIT_MODE)).booleanValue()) {
            tooltip.add("");
            tooltip.addAll(getAdvancedTooltip(quest, player, qID));
        }
        return tooltip;
    }

    private List<String> getStandardTooltip(IQuest quest, EntityPlayer player, int qID) {
        List<String> list = new ArrayList<>();
        list.add(QuestTranslation.translate((String) quest.getProperty(NativeProps.NAME), new Object[0]) + (!Minecraft.func_71410_x().field_71474_y.field_82882_x ? "" : " #" + qID));
        UUID playerID = QuestingAPI.getQuestingUUID(player);
        if (quest.isComplete(playerID)) {
            list.add(ChatFormatting.GREEN + QuestTranslation.translate("betterquesting.tooltip.complete", new Object[0]));
            if (!quest.hasClaimed(playerID)) {
                list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.rewards_pending", new Object[0]));
            } else if (((Integer) quest.getProperty(NativeProps.REPEAT_TIME)).intValue() > 0) {
                long time = getRepeatSeconds(quest, player);
                DecimalFormat df = new DecimalFormat("00");
                String timeTxt = "";
                if (time >= 3600) {
                    timeTxt = timeTxt + (time / 3600) + "h " + df.format((time % 3600) / 60) + "m ";
                } else if (time >= 60) {
                    timeTxt = timeTxt + (time / 60) + "m ";
                }
                list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.repeat", new Object[]{timeTxt + df.format(time % 60) + "s"}));
            }
        } else if (!quest.isUnlocked(playerID)) {
            list.add(ChatFormatting.RED + "" + ChatFormatting.UNDERLINE + QuestTranslation.translate("betterquesting.tooltip.requires", new Object[0]) + " (" + ((EnumLogic) quest.getProperty(NativeProps.LOGIC_QUEST)).toString().toUpperCase() + ")");
            for (DBEntry<IQuest> req : QuestDatabase.INSTANCE.bulkLookup(quest.getRequirements())) {
                if (!((IQuest) req.getValue()).isComplete(playerID)) {
                    list.add(ChatFormatting.RED + "- " + QuestTranslation.translate((String) ((IQuest) req.getValue()).getProperty(NativeProps.NAME), new Object[0]));
                }
            }
        } else {
            int n = 0;
            for (DBEntry<ITask> task : quest.getTasks().getEntries()) {
                if (((ITask) task.getValue()).isComplete(playerID)) {
                    n++;
                }
            }
            list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.tasks_complete", new Object[]{Integer.valueOf(n), Integer.valueOf(quest.getTasks().size())}));
        }
        return list;
    }

    private List<String> getAdvancedTooltip(IQuest quest, EntityPlayer player, int qID) {
        List<String> list = new ArrayList<>();
        list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.global_quest", new Object[]{quest.getProperty(NativeProps.GLOBAL)}));
        if (((Boolean) quest.getProperty(NativeProps.GLOBAL)).booleanValue()) {
            list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.global_share", new Object[]{quest.getProperty(NativeProps.GLOBAL_SHARE)}));
        }
        list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.quest_logic", new Object[]{((EnumLogic) quest.getProperty(NativeProps.LOGIC_QUEST)).toString().toUpperCase()}));
        list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.simultaneous", new Object[]{quest.getProperty(NativeProps.SIMULTANEOUS)}));
        list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.auto_claim", new Object[]{quest.getProperty(NativeProps.AUTO_CLAIM)}));
        if (((Integer) quest.getProperty(NativeProps.REPEAT_TIME)).intValue() >= 0) {
            long time = ((Integer) quest.getProperty(NativeProps.REPEAT_TIME)).intValue() / 20;
            DecimalFormat df = new DecimalFormat("00");
            String timeTxt = "";
            if (time >= 3600) {
                timeTxt = timeTxt + (time / 3600) + "h " + df.format((time % 3600) / 60) + "m ";
            } else if (time >= 60) {
                timeTxt = timeTxt + (time / 60) + "m ";
            }
            list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.repeat", new Object[]{timeTxt + df.format(time % 60) + "s"}));
        } else {
            list.add(ChatFormatting.GRAY + QuestTranslation.translate("betterquesting.tooltip.repeat", new Object[]{false}));
        }
        return list;
    }

    private long getRepeatSeconds(IQuest quest, EntityPlayer player) {
        if (((Integer) quest.getProperty(NativeProps.REPEAT_TIME)).intValue() < 0) {
            return -1L;
        }
        NBTTagCompound ue = quest.getCompletionInfo(QuestingAPI.getQuestingUUID(player));
        if (ue == null) {
            return 0L;
        }
        return ((((Integer) quest.getProperty(NativeProps.REPEAT_TIME)).intValue() * 50) - (System.currentTimeMillis() - ue.func_74763_f("timestamp"))) / 1000;
    }
}
